@@ -82,7 +82,7 @@ class TgWrap():
 
         # if we are using an 'init' together with update, add the `-upgrade` as well
         if command.lower() == 'init' and update:
-            update_stmt       = '--terragrunt-source-update -update'
+            update_stmt       = '--terragrunt-source-update -upgrade'
 
         if command not in ['clean']:
             full_command = commands.get(command, commands.get('generic')).format(
@@ -559,28 +559,32 @@ class TgWrap():
                     }
 
                     try:
-                        data = json.loads(plan_file)
+                        # plan file could be empty if module is skipped
+                        if len(plan_file) > 0:
+                            data = json.loads(plan_file)
 
-                        if 'resource_changes' in data and len(data['resource_changes']) > 0:
-                            for rc in data['resource_changes']:
-                                # check if we do have actual changes
-                                actions = rc['change']['actions']
-                                action = f'{rc["address"]}: {", ".join(actions)}'
-                                if len(actions) == 1 and (actions[0] == 'no-op' or actions[0] == 'read'):
-                                    pass # ignore, just an state change
-                                elif 'delete' in actions:
-                                    changes[module]["deletions"].append(action)
-                                else:
-                                    changes[module]["other"].append(action)
+                            if 'resource_changes' in data and len(data['resource_changes']) > 0:
+                                for rc in data['resource_changes']:
+                                    # check if we do have actual changes
+                                    actions = rc['change']['actions']
+                                    action = f'{rc["address"]}: {", ".join(actions)}'
+                                    if len(actions) == 1 and (actions[0] == 'no-op' or actions[0] == 'read'):
+                                        pass # ignore, just an state change
+                                    elif 'delete' in actions:
+                                        changes[module]["deletions"].append(action)
+                                    else:
+                                        changes[module]["other"].append(action)
 
-                        if ts_config:
-                            changes[module]["unauthorized"] = run_terrasafe(
-                                config=ts_config,
-                                data=data,
-                                verbose=self.printer.print_verbose,
-                                )
-                            if len(changes[module]["unauthorized"]) > 0:
-                                ts_validation_successful = False
+                            if ts_config:
+                                changes[module]["unauthorized"] = run_terrasafe(
+                                    config=ts_config,
+                                    data=data,
+                                    verbose=self.printer.print_verbose,
+                                    )
+                                if len(changes[module]["unauthorized"]) > 0:
+                                    ts_validation_successful = False
+                        else:
+                            self.printer.warning(f'Planfile for module {module} is empty')
                     except json.decoder.JSONDecodeError as e:
                         raise Exception(
                             f"Planfile for {module} was no proper json, further analysis not possible."
